@@ -2,8 +2,8 @@ var NAVTREE =
 [
   [ "OpenMesh", "index.html", [
     [ "OpenMesh Documentation", "index.html", "index" ],
-    [ "Todo List", "a00758.html", null ],
-    [ "Deprecated List", "a00760.html", null ],
+    [ "Todo List", "a00759.html", null ],
+    [ "Deprecated List", "a00761.html", null ],
     [ "Modules", "modules.html", "modules" ],
     [ "Namespaces", null, [
       [ "Namespace List", "namespaces.html", "namespaces" ],
@@ -45,21 +45,21 @@ var NAVTREEINDEX =
 "a00082.html#a46f745e0db2bd441cc6d00cb1a028ebe",
 "a00086.html#ad93559cb53cf3ca7648508764ba4b2a4",
 "a00092.html#aaca3881714c7bf5c30e8a93bdb8ef8d8",
-"a00100.html#ac3c0fcb247b70c6f6a37b8c37b4e1863",
-"a00130.html#a2e2b51cb38ba9d88ffe1e99f668a089a",
-"a00158.html#a3c9b092336a8cb70c3d3ce9d92663042",
-"a00191.html#ac1fb9239612211caa02700db410df1f4",
-"a00198.html#aebd448c2a612a801147f62656d605208",
-"a00222.html#a4e638750b7aa9c885dfa88ffba72ded4",
-"a00244.html#a4c2bbb43717623b1836fcf533e849b49",
-"a00247.html#a71aecb0f5c3cd117fdcbeb686704c95b",
-"a00250.html#a5ec24476d2513efe71ddd1255a2ca444",
-"a00259.html#ad984e8acf6e5ae854bc7979addaedbb6",
-"a00276.html#a129372ccc43d66a01dd92e635b8419fda4e9f45facaa41709d1f7a15f1ac664ff",
-"a00298.html#a8f51284c13cfadd09cb362d52f7af2ad",
-"a00327.html#a5691b439a530e99d8e656d4ccd84db1e",
-"a00569_source.html",
-"functions_type_e.html"
+"a00100.html#a7c0818a63926bdb439044a8f4c038d85",
+"a00130.html#a070b88501d483e9fe71cf89564ad5e8c",
+"a00157.html#a86044009e52dbe1529df079132aa1989",
+"a00191.html#ab4c7c7f195ec9712844f3d5323c2515e",
+"a00198.html#ae9d88f789c86889343181ee5f2c0cff8",
+"a00222.html#a3c67a7da2ea2955ae2eac9d095bd4e89",
+"a00244.html#a4acad4b623093d8b3673db32c802d331",
+"a00247.html#a7020b3403b050cb059e08f239223cd08",
+"a00250.html#a5d0ff00a35aa4b3ebfa554441def1334a728dfa21d7d5250680882d1b5fed00d1",
+"a00259.html#ad00f454abddf47fa0cd9526e37774b28",
+"a00276.html#a129372ccc43d66a01dd92e635b8419fda4a9e6bfd304ff90dae6f2c56aa8e9fb0",
+"a00298.html#a0c5b1dc5b8a2a073ec17f2e5705c09bc",
+"a00327.html#a431e910efd64bb1f4188d6b77f5430b1",
+"a00568.html",
+"functions_type.html"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
