@@ -41,8 +41,8 @@
 
 /*===========================================================================*\
  *                                                                           *             
- *   $Revision: 1258 $                                                         *
- *   $Date: 2015-04-28 15:07:46 +0200 (Di, 28 Apr 2015) $                   *
+ *   $Revision$                                                         *
+ *   $Date$                   *
  *                                                                           *
 \*===========================================================================*/
 
@@ -56,8 +56,6 @@
 //== INCLUDES =================================================================
 
 #include <OpenMesh/Core/IO/OMFormat.hh>
-#include <algorithm>
-#include <iomanip>
 
 //== NAMESPACES ===============================================================
 
